@@ -9,6 +9,11 @@
 #else
 # define ECL_NAME(x) NULL
 #endif
+#ifdef ECL_RELATIVE_PACKAGE_NAMES
+# define RELATIVE_PACKAGES_P Ct
+#else
+# define RELATIVE_PACKAGES_P Cnil
+#endif
 #ifdef DPP
 #define CLOS_ "CLOS::"
 #define EXT_ "EXT::"
@@ -1109,9 +1114,7 @@ cl_symbols[] = {
 {SYS_ "FRS-TOP", SI_ORDINARY, si_frs_top, 0, OBJNULL},
 {SYS_ "FSET", SI_ORDINARY, si_fset, -1, OBJNULL},
 {SYS_ "FUNCTION-BLOCK-NAME", SI_ORDINARY, si_function_block_name, 1, OBJNULL},
-#if defined(_MSC_VER) || defined(mingw32)
 {SYS_ "GET-LIBRARY-PATHNAME", SI_ORDINARY, si_get_library_pathname, 0, OBJNULL},
-#endif
 {SYS_ "GET-SYSPROP", SI_ORDINARY, si_get_sysprop, 2, OBJNULL},
 {EXT_ "GETENV", SI_ORDINARY, si_getenv, 1, OBJNULL},
 {EXT_ "GETCWD", SI_ORDINARY, si_getcwd, -1, OBJNULL},
@@ -1122,7 +1125,7 @@ cl_symbols[] = {
 {SYS_ "IHS-FUN", SI_ORDINARY, si_ihs_fun, 1, OBJNULL},
 {SYS_ "IHS-NEXT", SI_ORDINARY, si_ihs_next, 1, OBJNULL},
 {SYS_ "IHS-PREV", SI_ORDINARY, si_ihs_prev, 1, OBJNULL},
-{SYS_ "IHS-TOP", SI_ORDINARY, si_ihs_top, 1, OBJNULL},
+{SYS_ "IHS-TOP", SI_ORDINARY, si_ihs_top, 0, OBJNULL},
 {SYS_ "INTERPRETER-STACK", SI_ORDINARY, si_interpreter_stack, -1, OBJNULL},
 {SYS_ "LINK-FROM", SI_ORDINARY, NULL, -1, OBJNULL},
 {SYS_ "LINK-TO", SI_ORDINARY, NULL, -1, OBJNULL},
@@ -1196,7 +1199,6 @@ cl_symbols[] = {
 {SYS_ "TERMINAL-INTERRUPT", SI_ORDINARY, NULL, -1, OBJNULL},
 {SYS_ "TOP-LEVEL", SI_ORDINARY, NULL, -1, OBJNULL},
 {SYS_ "UNIVERSAL-ERROR-HANDLER", SI_ORDINARY, NULL, -1, OBJNULL},
-{SYS_ "UNLINK-SYMBOL", SI_ORDINARY, si_unlink_symbol, 1, OBJNULL},
 {SYS_ "VALID-FUNCTION-NAME-P", SI_ORDINARY, si_valid_function_name_p, 1, OBJNULL},
 {SYS_ "WRITE-OBJECT", SI_SPECIAL, si_write_object, 2, OBJNULL},
 {SYS_ "WRITE-UGLY-OBJECT", SI_SPECIAL, si_write_ugly_object, 2, OBJNULL},
@@ -1369,7 +1371,7 @@ cl_symbols[] = {
 {KEY_ "UP", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "UPCASE", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "USE", KEYWORD, NULL, -1, OBJNULL},
-{KEY_ "USE-HEADER-P", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "CSTREAM", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "VERBOSE", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "VERSION", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "WILD", KEYWORD, NULL, -1, OBJNULL},
@@ -1377,8 +1379,14 @@ cl_symbols[] = {
 {KEY_ "WAIT", KEYWORD, NULL, -1, OBJNULL},
 
 {EXT_ "BYTE8", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "BYTE16", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "BYTE32", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "BYTE64", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "COMPILER-LET", EXT_FORM, NULL, -1, OBJNULL},
 {EXT_ "INTEGER8", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "INTEGER16", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "INTEGER32", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "INTEGER64", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "LAMBDA-BLOCK", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "QUIT", EXT_ORDINARY, si_quit, -1, OBJNULL},
 #ifdef CLOS
@@ -1409,17 +1417,27 @@ cl_symbols[] = {
 {KEY_ "FIXNUM", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "FLOAT", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "INT", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "INT8-T", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "INT16-T", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "INT32-T", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "INT64-T", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "LONG", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "LONG-LONG", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "POINTER-SELF", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "POINTER-VOID", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "SHORT", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "STRUCT", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "UNION", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "VOID", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UINT8-T", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UINT16-T", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UINT32-T", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UINT64-T", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "UNSIGNED-BYTE", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "UNSIGNED-CHAR", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "UNSIGNED-INT", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "UNSIGNED-LONG", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UNSIGNED-LONG-LONG", KEYWORD, NULL, -1, OBJNULL},
 {KEY_ "UNSIGNED-SHORT", KEYWORD, NULL, -1, OBJNULL},
 {SYS_ "C-CHAR-BIT", SI_CONSTANT, NULL, -1, MAKE_FIXNUM(CHAR_BIT)},
 {SYS_ "C-CHAR-MAX", SI_CONSTANT, NULL, -1, MAKE_FIXNUM(CHAR_MAX)},
@@ -1434,7 +1452,7 @@ cl_symbols[] = {
 {SYS_ "C-UINT-MAX", SI_CONSTANT, NULL, -1, OBJNULL}, /* See main.d */
 {SYS_ "C-USHORT-MAX", SI_CONSTANT, NULL, -1, MAKE_FIXNUM(USHRT_MAX)},
 {SYS_ "C-ULONG-MAX", SI_CONSTANT, NULL, -1, OBJNULL}, /* See main.d */
-
+{SYS_ "C-ULONG-LONG-MAX",SI_CONSTANT,NULL,-1,OBJNULL}, /* See main.d */
 #ifdef GBC_BOEHM
 {SYS_ "GC", SI_ORDINARY, si_gc, 1, OBJNULL},
 {SYS_ "GC-DUMP", SI_ORDINARY, si_gc_dump, 0, OBJNULL},
@@ -1489,7 +1507,6 @@ cl_symbols[] = {
 {MP_ "+LOAD-COMPILE-LOCK+", MP_CONSTANT, NULL, -1, OBJNULL},
 {MP_ "WITH-LOCK", MP_CONSTANT, NULL, -1, OBJNULL},
 {MP_ "WITHOUT-INTERRUPTS", MP_CONSTANT, NULL, -1, OBJNULL},
-{MP_ "CHECK-PENDING-INTERRUPTS", SI_ORDINARY, si_check_pending_interrupts, 0, OBJNULL},
 #endif
 
 {SYS_ "WHILE", SI_ORDINARY, NULL, -1, OBJNULL},
@@ -1621,7 +1638,7 @@ cl_symbols[] = {
 {SYS_ "SET-FINALIZER", SI_ORDINARY, si_set_finalizer, 2, OBJNULL},
 
 #ifdef ECL_RELATIVE_PACKAGE_NAMES
-{SYS_ "*RELATIVE-PACKAGE-NAMES*", SI_SPECIAL, NULL, -1, Cnil},
+{SYS_ "*RELATIVE-PACKAGE-NAMES*", SI_SPECIAL, NULL, -1, RELATIVE_PACKAGES_P},
 {KEY_ "RELATIVE-PACKAGE-NAMES", KEYWORD, NULL, -1, OBJNULL},
 {SYS_ "FIND-RELATIVE-PACKAGE", SI_ORDINARY, si_find_relative_package, -1, OBJNULL},
 {SYS_ "PACKAGE-PARENT", SI_ORDINARY, NULL, -1, OBJNULL},
@@ -1688,7 +1705,8 @@ cl_symbols[] = {
 
 {"LOG1P", SI_ORDINARY, si_log1p, 1, OBJNULL},
 
-{EXT_ "BC-FILE", EXT_ORDINARY, si_bc_file, 1, Cnil},
+{EXT_ "BC-FILE", EXT_ORDINARY, si_compiled_function_file, 1, Cnil},
+{EXT_ "COMPILED-FUNCTION-FILE", EXT_ORDINARY, si_compiled_function_file, 1, Cnil},
 
 {SYS_ "PROPERTY-LIST", SI_ORDINARY, NULL, 1, OBJNULL},
 
@@ -1700,6 +1718,7 @@ cl_symbols[] = {
 
 {EXT_ "INTERACTIVE-INTERRUPT", EXT_ORDINARY, NULL, -1, OBJNULL},
 
+{EXT_ "STORAGE-EXHAUSTED", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "STACK-OVERFLOW", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "STACK-OVERFLOW-SIZE", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "STACK-OVERFLOW-TYPE", EXT_ORDINARY, NULL, -1, OBJNULL},
@@ -1707,10 +1726,64 @@ cl_symbols[] = {
 {EXT_ "FRAME-STACK", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "LISP-STACK", EXT_ORDINARY, NULL, -1, OBJNULL},
 {EXT_ "C-STACK", EXT_ORDINARY, NULL, -1, OBJNULL},
-{EXT_ "SET-STACK-SIZE", EXT_ORDINARY, si_set_stack_size, 2, OBJNULL},
+{EXT_ "HEAP-SIZE", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "SET-LIMIT", EXT_ORDINARY, si_set_limit, 2, OBJNULL},
+{EXT_ "GET-LIMIT", EXT_ORDINARY, si_get_limit, 1, OBJNULL},
 {EXT_ "SEGMENTATION-VIOLATION", EXT_ORDINARY, NULL, -1, OBJNULL},
 
 {EXT_ "EXTENDED-STRING", EXT_ORDINARY, NULL, -1, OBJNULL},
 
+{SYS_ "CHECK-PENDING-INTERRUPTS", SI_ORDINARY, si_check_pending_interrupts, 0, OBJNULL},
+
+{KEY_ "LATIN-1", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "ISO-8859-1", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UTF-8", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UCS-2", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UCS-4", KEYWORD, NULL, -1, OBJNULL},
+
+{EXT_ "CONSTANTLY-T", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "CONSTANTLY-NIL", EXT_ORDINARY, NULL, -1, OBJNULL},
+
+{EXT_ "MAYBE-QUOTE", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "MAYBE-UNQUOTE", EXT_ORDINARY, NULL, -1, OBJNULL},
+
+{KEY_ "CR", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "LF", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "CRLF", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UCS-2BE", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UCS-4BE", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UCS-2LE", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "UCS-4LE", KEYWORD, NULL, -1, OBJNULL},
+
+{EXT_ "LOAD-ENCODING", EXT_ORDINARY, NULL, -1, OBJNULL},
+{EXT_ "MAKE-ENCODING", EXT_ORDINARY, NULL, -1, OBJNULL},
+
+{KEY_ "US-ASCII", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "LITTLE-ENDIAN", KEYWORD, NULL, -1, OBJNULL},
+{KEY_ "BIG-ENDIAN", KEYWORD, NULL, -1, OBJNULL},
+
+{SYS_ "+UNICODE-DATABASE+", SI_CONSTANT, NULL, -1, Cnil},
+
+{SYS_ "COPY-FILE", SI_ORDINARY, si_copy_file, 2, OBJNULL},
+
+{EXT_ "FILL-ARRAY-WITH-ELT", EXT_ORDINARY, si_fill_array_with_elt, 4, OBJNULL},
+
+{EXT_ "+ECL-VERSION-NUMBER+", EXT_CONSTANT, NULL, -1, MAKE_FIXNUM(ECL_VERSION_NUMBER)},
+
+{EXT_ "*BYTECODES-COMPILER*", EXT_SPECIAL, NULL, -1, Cnil},
+
+{EXT_ "SHORT-FLOAT-POSITIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "SINGLE-FLOAT-POSITIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "DOUBLE-FLOAT-POSITIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "LONG-FLOAT-POSITIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "SHORT-FLOAT-NEGATIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "SINGLE-FLOAT-NEGATIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "DOUBLE-FLOAT-NEGATIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "LONG-FLOAT-NEGATIVE-INFINITY", EXT_CONSTANT, NULL, -1, OBJNULL},
+{EXT_ "FLOAT-NAN-P", EXT_ORDINARY, si_float_nan_p, 1, OBJNULL},
+{EXT_ "FLOAT-INFINITY-P", EXT_ORDINARY, si_float_infinity_p, 1, OBJNULL},
+
+{SYS_ "READ-OBJECT-OR-IGNORE", EXT_ORDINARY, si_read_object_or_ignore, 2, OBJNULL},
+
 /* Tag for end of list */
 {NULL, CL_ORDINARY, NULL, -1, OBJNULL}};
