@@ -9,6 +9,11 @@
 #else
 # define ECL_NAME(x) NULL
 #endif
+#ifdef ECL_RELATIVE_PACKAGE_NAMES
+# define RELATIVE_PACKAGES_P Ct
+#else
+# define RELATIVE_PACKAGES_P Cnil
+#endif
 #ifdef DPP
 #define CLOS_ "CLOS::"
 #define EXT_ "EXT::"
@@ -1109,9 +1114,7 @@ cl_symbols[] = {
 {SYS_ "FRS-TOP","si_frs_top"},
 {SYS_ "FSET","si_fset"},
 {SYS_ "FUNCTION-BLOCK-NAME","si_function_block_name"},
-#if defined(_MSC_VER) || defined(mingw32)
 {SYS_ "GET-LIBRARY-PATHNAME","si_get_library_pathname"},
-#endif
 {SYS_ "GET-SYSPROP","si_get_sysprop"},
 {EXT_ "GETENV","si_getenv"},
 {EXT_ "GETCWD","si_getcwd"},
@@ -1196,7 +1199,6 @@ cl_symbols[] = {
 {SYS_ "TERMINAL-INTERRUPT",NULL},
 {SYS_ "TOP-LEVEL",NULL},
 {SYS_ "UNIVERSAL-ERROR-HANDLER",NULL},
-{SYS_ "UNLINK-SYMBOL","si_unlink_symbol"},
 {SYS_ "VALID-FUNCTION-NAME-P","si_valid_function_name_p"},
 {SYS_ "WRITE-OBJECT","si_write_object"},
 {SYS_ "WRITE-UGLY-OBJECT","si_write_ugly_object"},
@@ -1369,7 +1371,7 @@ cl_symbols[] = {
 {KEY_ "UP",NULL},
 {KEY_ "UPCASE",NULL},
 {KEY_ "USE",NULL},
-{KEY_ "USE-HEADER-P",NULL},
+{KEY_ "CSTREAM",NULL},
 {KEY_ "VERBOSE",NULL},
 {KEY_ "VERSION",NULL},
 {KEY_ "WILD",NULL},
@@ -1377,8 +1379,14 @@ cl_symbols[] = {
 {KEY_ "WAIT",NULL},
 
 {EXT_ "BYTE8",NULL},
+{EXT_ "BYTE16",NULL},
+{EXT_ "BYTE32",NULL},
+{EXT_ "BYTE64",NULL},
 {EXT_ "COMPILER-LET",NULL},
 {EXT_ "INTEGER8",NULL},
+{EXT_ "INTEGER16",NULL},
+{EXT_ "INTEGER32",NULL},
+{EXT_ "INTEGER64",NULL},
 {EXT_ "LAMBDA-BLOCK",NULL},
 {EXT_ "QUIT","si_quit"},
 #ifdef CLOS
@@ -1409,17 +1417,27 @@ cl_symbols[] = {
 {KEY_ "FIXNUM",NULL},
 {KEY_ "FLOAT",NULL},
 {KEY_ "INT",NULL},
+{KEY_ "INT8-T",NULL},
+{KEY_ "INT16-T",NULL},
+{KEY_ "INT32-T",NULL},
+{KEY_ "INT64-T",NULL},
 {KEY_ "LONG",NULL},
+{KEY_ "LONG-LONG",NULL},
 {KEY_ "POINTER-SELF",NULL},
 {KEY_ "POINTER-VOID",NULL},
 {KEY_ "SHORT",NULL},
 {KEY_ "STRUCT",NULL},
 {KEY_ "UNION",NULL},
 {KEY_ "VOID",NULL},
+{KEY_ "UINT8-T",NULL},
+{KEY_ "UINT16-T",NULL},
+{KEY_ "UINT32-T",NULL},
+{KEY_ "UINT64-T",NULL},
 {KEY_ "UNSIGNED-BYTE",NULL},
 {KEY_ "UNSIGNED-CHAR",NULL},
 {KEY_ "UNSIGNED-INT",NULL},
 {KEY_ "UNSIGNED-LONG",NULL},
+{KEY_ "UNSIGNED-LONG-LONG",NULL},
 {KEY_ "UNSIGNED-SHORT",NULL},
 {SYS_ "C-CHAR-BIT",NULL},
 {SYS_ "C-CHAR-MAX",NULL},
@@ -1434,7 +1452,7 @@ cl_symbols[] = {
 {SYS_ "C-UINT-MAX",NULL}, /* See main.d */
 {SYS_ "C-USHORT-MAX",NULL},
 {SYS_ "C-ULONG-MAX",NULL}, /* See main.d */
-
+{SYS_ "C-ULONG-LONG-MAX",NULL}, /* See main.d */
 #ifdef GBC_BOEHM
 {SYS_ "GC","si_gc"},
 {SYS_ "GC-DUMP","si_gc_dump"},
@@ -1489,7 +1507,6 @@ cl_symbols[] = {
 {MP_ "+LOAD-COMPILE-LOCK+",NULL},
 {MP_ "WITH-LOCK",NULL},
 {MP_ "WITHOUT-INTERRUPTS",NULL},
-{MP_ "CHECK-PENDING-INTERRUPTS","si_check_pending_interrupts"},
 #endif
 
 {SYS_ "WHILE",NULL},
@@ -1688,7 +1705,8 @@ cl_symbols[] = {
 
 {"LOG1P","si_log1p"},
 
-{EXT_ "BC-FILE","si_bc_file"},
+{EXT_ "BC-FILE","si_compiled_function_file"},
+{EXT_ "COMPILED-FUNCTION-FILE","si_compiled_function_file"},
 
 {SYS_ "PROPERTY-LIST",NULL},
 
@@ -1700,6 +1718,7 @@ cl_symbols[] = {
 
 {EXT_ "INTERACTIVE-INTERRUPT",NULL},
 
+{EXT_ "STORAGE-EXHAUSTED",NULL},
 {EXT_ "STACK-OVERFLOW",NULL},
 {EXT_ "STACK-OVERFLOW-SIZE",NULL},
 {EXT_ "STACK-OVERFLOW-TYPE",NULL},
@@ -1707,10 +1726,64 @@ cl_symbols[] = {
 {EXT_ "FRAME-STACK",NULL},
 {EXT_ "LISP-STACK",NULL},
 {EXT_ "C-STACK",NULL},
-{EXT_ "SET-STACK-SIZE","si_set_stack_size"},
+{EXT_ "HEAP-SIZE",NULL},
+{EXT_ "SET-LIMIT","si_set_limit"},
+{EXT_ "GET-LIMIT","si_get_limit"},
 {EXT_ "SEGMENTATION-VIOLATION",NULL},
 
 {EXT_ "EXTENDED-STRING",NULL},
 
+{SYS_ "CHECK-PENDING-INTERRUPTS","si_check_pending_interrupts"},
+
+{KEY_ "LATIN-1",NULL},
+{KEY_ "ISO-8859-1",NULL},
+{KEY_ "UTF-8",NULL},
+{KEY_ "UCS-2",NULL},
+{KEY_ "UCS-4",NULL},
+
+{EXT_ "CONSTANTLY-T",NULL},
+{EXT_ "CONSTANTLY-NIL",NULL},
+
+{EXT_ "MAYBE-QUOTE",NULL},
+{EXT_ "MAYBE-UNQUOTE",NULL},
+
+{KEY_ "CR",NULL},
+{KEY_ "LF",NULL},
+{KEY_ "CRLF",NULL},
+{KEY_ "UCS-2BE",NULL},
+{KEY_ "UCS-4BE",NULL},
+{KEY_ "UCS-2LE",NULL},
+{KEY_ "UCS-4LE",NULL},
+
+{EXT_ "LOAD-ENCODING",NULL},
+{EXT_ "MAKE-ENCODING",NULL},
+
+{KEY_ "US-ASCII",NULL},
+{KEY_ "LITTLE-ENDIAN",NULL},
+{KEY_ "BIG-ENDIAN",NULL},
+
+{SYS_ "+UNICODE-DATABASE+",NULL},
+
+{SYS_ "COPY-FILE","si_copy_file"},
+
+{EXT_ "FILL-ARRAY-WITH-ELT","si_fill_array_with_elt"},
+
+{EXT_ "+ECL-VERSION-NUMBER+",NULL},
+
+{EXT_ "*BYTECODES-COMPILER*",NULL},
+
+{EXT_ "SHORT-FLOAT-POSITIVE-INFINITY",NULL},
+{EXT_ "SINGLE-FLOAT-POSITIVE-INFINITY",NULL},
+{EXT_ "DOUBLE-FLOAT-POSITIVE-INFINITY",NULL},
+{EXT_ "LONG-FLOAT-POSITIVE-INFINITY",NULL},
+{EXT_ "SHORT-FLOAT-NEGATIVE-INFINITY",NULL},
+{EXT_ "SINGLE-FLOAT-NEGATIVE-INFINITY",NULL},
+{EXT_ "DOUBLE-FLOAT-NEGATIVE-INFINITY",NULL},
+{EXT_ "LONG-FLOAT-NEGATIVE-INFINITY",NULL},
+{EXT_ "FLOAT-NAN-P","si_float_nan_p"},
+{EXT_ "FLOAT-INFINITY-P","si_float_infinity_p"},
+
+{SYS_ "READ-OBJECT-OR-IGNORE","si_read_object_or_ignore"},
+
 /* Tag for end of list */
 {NULL,NULL}};
